<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Food Restro Pro
 * @since Food Restro Pro 1.0.0
 * @return array An array of default values
 */

function food_restro_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$food_restro_pro_default_options = array(
		// Color Options
		'header_title_color'			=> '#fff',
		'header_tagline_color'			=> '#fff',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#000',
		'colorscheme'					=> 'default',
		'theme_version'					=> 'lite-version',
		
		// typography options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',
		
		// loader
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'default',

		// breadcrumb
		'breadcrumb_enable'				=> true,
		'breadcrumb_separator'			=> '/',
		
		// layout 
		'site_layout'         			=> 'wide',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'menu_sticky'					=> true,
		'nav_search_enable'				=> true,

		// excerpt options
		'long_excerpt_length'           => 25,
		
		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s', '1: Year, 2: Site Title with home URL', 'food-restro-pro' ), '[the-year]', '[site-link]' ),
		'powered_by_text'           	=> esc_html__( 'All Rights Reserved | ', 'food-restro-pro' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'food-restro-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',
		'scroll_top_visible'        	=> true,

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		// homepage sections sortable
		'sortable' 						=> 'Main Slider,Services,About Us,Special Menu,Special Offer,Gallery,Testimonial,Call to Action,Blog',

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'food-restro-pro' ),
		'hide_date' 					=> false,
		'hide_category'					=> false,
		'archive_column'				=> 'col-1',

		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_author'		=> false,
		'single_post_hide_category'		=> false,
		'single_post_hide_tags'			=> false,

		/* Front Page */

		// topbar
		'topbar_section_enable'			=> true,
		'topbar_social_enable'			=> false,
		'topbar_phone_label'			=> esc_html__( 'Any Questions? Call Us:', 'food-restro-pro' ),
		'topbar_phone'					=> esc_html__( '+0 00 000000000', 'food-restro-pro' ),

		// Slider
		'slider_section_enable'			=> true,
		'slider_content_type'			=> 'category',
		'slider_count'					=> 3,
		'slider_btn_label'				=> esc_html__( 'Learn More', 'food-restro-pro' ),

		// service
		'service_section_enable'		=> true,
		'service_content_type'			=> 'category',
		'service_count'					=> 6,
		'service_column'				=> 'col-3',
		'service_title'					=> esc_html__( 'How Good We Are', 'food-restro-pro' ),
		'service_subtitle'				=> esc_html__( 'Our Services', 'food-restro-pro' ), 

		// About
		'about_section_enable'			=> true,
		'about_content_type'			=> 'page',
		'about_title'					=> esc_html__( 'White high rise building by Michal Nowak', 'food-restro-pro' ),
		'about_subtitle'				=> esc_html__( 'About Us', 'food-restro-pro' ),
		'about_description'				=> esc_html__( 'Lorem ipsum dolor sit amet, con sectetur adipiscing elit. Etiam euismod pulvinar velit id commodo. Aenean id varius libLorem ipsum dolor sit amet, consectetur adipiscing elit. Etiam euismod pulvinar velit id commodo. Aenean id varius libero. Curabitur sit amet eros velit. Fusce sed cursus quam. Nam sit amet sapien eu lorem fringilla ullamcorper. Integer fermentum erat gravida, sagittis quam in, condimentum ligula.', 'food-restro-pro' ),

		// Special Menu
		'special_menu_section_enable'	=> true,
		'special_menu_content_type'		=> 'category',
		'special_menu_count'			=> 4,
		'special_menu_title'			=> esc_html__( 'Explore Delicious Flavour', 'food-restro-pro' ),
		'special_menu_subtitle'			=> esc_html__( 'Special Menu', 'food-restro-pro' ),

		// Special Offer
		'special_offer_section_enable'	=> true,
		'special_offer_content_type'	=> 'page',
		'special_offer_title'			=> esc_html__( 'Delicious Spicy Noodles', 'food-restro-pro' ),
		'special_offer_subtitle'		=> esc_html__( 'Special Offer', 'food-restro-pro' ),
		'special_offer_description'		=> esc_html__( 'Lorem ipsum dolor sit amet, con sectetur adipiscing elit. Etiam euismod pulvinar velit id commodo. Aenean id varius libLorem ipsum dolor sit amet, consectetur adipiscing elit. Etiam euismod pulvinar velit id commodo. Aenean id varius libero. Curabitur sit amet eros velit. Fusce sed cursus quam. Nam sit amet sapien eu lorem fringilla ullamcorper. Integer fermentum erat gravida, sagittis quam in, condimentum ligula.', 'food-restro-pro' ),

		// Gallery
		'gallery_section_enable'		=> true,
		'gallery_content_type'			=> 'category',
		'gallery_count'					=> 8,
		'gallery_column'				=> 'col-4',

		// testimonial
		'testimonial_section_enable'	=> true,
		'testimonial_content_type'		=> 'category',
		'testimonial_count'				=> 3,
		'testimonial_title'				=> esc_html__( 'Our Foodie Fan Here', 'food-restro-pro' ),
		'testimonial_subtitle'			=> esc_html__( 'Testimonial', 'food-restro-pro' ),

		// call to action
		'cta_section_enable'			=> true,
		'cta_content_type'				=> 'custom',
		'cta_title'						=> esc_html__( 'Fine &amp; Delicious Food', 'food-restro-pro' ),
		'cta_subtitle'					=> esc_html__( 'Call To Action', 'food-restro-pro' ),
		'cta_image'						=> get_template_directory_uri() . '/assets/uploads/call-to-action.jpg',

		// blog
		'blog_section_enable'			=> true,
		'blog_content_type'				=> 'category',
		'blog_count'					=> 3,
		'blog_column'					=> 'col-3',
		'blog_title'					=> esc_html__( 'Our Yummy Story', 'food-restro-pro' ),
		'blog_subtitle'					=> esc_html__( 'Latest Blog', 'food-restro-pro' ),
		'blog_btn_title'				=> esc_html__( 'View All Posts', 'food-restro-pro' ),

		// subscribe
		'subscribe_section_enable'		=> true,
		'subscribe_footer_attach'		=> true,
		'subscribe_title'				=> esc_html__( 'Opening - Closing Time', 'food-restro-pro' ),
		'subscribe_subtitle'			=> esc_html__( 'Available Daily, 9am-10pm', 'food-restro-pro' ),

	);

	$output = apply_filters( 'food_restro_pro_default_theme_options', $food_restro_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}