<?php
/**
 * Special Menu Section options
 *
 * @package Theme Palace
 * @subpackage Food Restro Pro
 * @since Food Restro Pro 1.0.0
 */

// Add Special Menu section
$wp_customize->add_section( 'food_restro_pro_special_menu_section', array(
	'title'             => esc_html__( 'Special Menu','food-restro-pro' ),
	'description'       => esc_html__( 'Special Menu Section options.', 'food-restro-pro' ),
	'panel'             => 'food_restro_pro_front_page_panel',
) );

// Special Menu content enable control and setting
$wp_customize->add_setting( 'food_restro_pro_theme_options[special_menu_section_enable]', array(
	'default'			=> 	$options['special_menu_section_enable'],
	'sanitize_callback' => 'food_restro_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Food_Restro_Pro_Switch_Control( $wp_customize, 'food_restro_pro_theme_options[special_menu_section_enable]', array(
	'label'             => esc_html__( 'Special Menu Section Enable', 'food-restro-pro' ),
	'section'           => 'food_restro_pro_special_menu_section',
	'on_off_label' 		=> food_restro_pro_switch_options(),
) ) );

// special_menu subtitle setting and control
$wp_customize->add_setting( 'food_restro_pro_theme_options[special_menu_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['special_menu_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'food_restro_pro_theme_options[special_menu_subtitle]', array(
	'label'           	=> esc_html__( 'Sub Title', 'food-restro-pro' ),
	'section'        	=> 'food_restro_pro_special_menu_section',
	'active_callback' 	=> 'food_restro_pro_is_special_menu_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'food_restro_pro_theme_options[special_menu_subtitle]', array(
		'selector'            => '#special-menu .section-header p.section-subtitle',
		'settings'            => 'food_restro_pro_theme_options[special_menu_subtitle]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'food_restro_pro_special_menu_subtitle_partial',
    ) );
}

// special_menu title setting and control
$wp_customize->add_setting( 'food_restro_pro_theme_options[special_menu_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['special_menu_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'food_restro_pro_theme_options[special_menu_title]', array(
	'label'           	=> esc_html__( 'Title', 'food-restro-pro' ),
	'section'        	=> 'food_restro_pro_special_menu_section',
	'active_callback' 	=> 'food_restro_pro_is_special_menu_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'food_restro_pro_theme_options[special_menu_title]', array(
		'selector'            => '#special-menu .section-header h2.section-title',
		'settings'            => 'food_restro_pro_theme_options[special_menu_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'food_restro_pro_special_menu_title_partial',
    ) );
}

// Special Menu content type control and setting
$wp_customize->add_setting( 'food_restro_pro_theme_options[special_menu_content_type]', array(
	'default'          	=> $options['special_menu_content_type'],
	'sanitize_callback' => 'food_restro_pro_sanitize_select',
) );

$wp_customize->add_control( 'food_restro_pro_theme_options[special_menu_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'food-restro-pro' ),
	'section'           => 'food_restro_pro_special_menu_section',
	'type'				=> 'select',
	'active_callback' 	=> 'food_restro_pro_is_special_menu_section_enable',
	'choices'			=> food_restro_pro_special_menu_content_type(),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'food_restro_pro_theme_options[special_menu_count]', array(
	'default'          	=> $options['special_menu_count'],
	'sanitize_callback' => 'food_restro_pro_sanitize_number_range',
	'validate_callback' => 'food_restro_pro_validate_special_menu_count',
) );

$wp_customize->add_control( 'food_restro_pro_theme_options[special_menu_count]', array(
	'label'             => esc_html__( 'Number of Special Menu', 'food-restro-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'food-restro-pro' ),
	'section'           => 'food_restro_pro_special_menu_section',
	'active_callback'   => 'food_restro_pro_is_special_menu_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['special_menu_count']; $i++ ) :

	// special_menu posts drop down chooser control and setting
	$wp_customize->add_setting( 'food_restro_pro_theme_options[special_menu_content_page_' . $i . ']', array(
		'sanitize_callback' => 'food_restro_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Food_Restro_Pro_Dropdown_Chooser( $wp_customize, 'food_restro_pro_theme_options[special_menu_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'food-restro-pro' ), $i ),
		'section'           => 'food_restro_pro_special_menu_section',
		'choices'			=> food_restro_pro_page_choices(),
		'active_callback'	=> 'food_restro_pro_is_special_menu_section_content_page_enable',
	) ) );

	// special_menu posts drop down chooser control and setting
	$wp_customize->add_setting( 'food_restro_pro_theme_options[special_menu_content_post_' . $i . ']', array(
		'sanitize_callback' => 'food_restro_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Food_Restro_Pro_Dropdown_Chooser( $wp_customize, 'food_restro_pro_theme_options[special_menu_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'food-restro-pro' ), $i ),
		'section'           => 'food_restro_pro_special_menu_section',
		'choices'			=> food_restro_pro_post_choices(),
		'active_callback'	=> 'food_restro_pro_is_special_menu_section_content_post_enable',
	) ) );

	// special_menu posts drop down chooser control and setting
	$wp_customize->add_setting( 'food_restro_pro_theme_options[special_menu_content_product_' . $i . ']', array(
		'sanitize_callback' => 'food_restro_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Food_Restro_Pro_Dropdown_Chooser( $wp_customize, 'food_restro_pro_theme_options[special_menu_content_product_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Product %d', 'food-restro-pro' ), $i ),
		'section'           => 'food_restro_pro_special_menu_section',
		'choices'			=> food_restro_pro_product_choices(),
		'active_callback'	=> 'food_restro_pro_is_special_menu_section_content_product_enable',
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'food_restro_pro_theme_options[special_menu_content_category]', array(
	'sanitize_callback' => 'food_restro_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Food_Restro_Pro_Dropdown_Taxonomies_Control( $wp_customize,'food_restro_pro_theme_options[special_menu_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'food-restro-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'food-restro-pro' ),
	'section'           => 'food_restro_pro_special_menu_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'food_restro_pro_is_special_menu_section_content_category_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'food_restro_pro_theme_options[special_menu_content_product_category]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Food_Restro_Pro_Dropdown_Taxonomies_Control( $wp_customize,'food_restro_pro_theme_options[special_menu_content_product_category]', array(
	'label'             => esc_html__( 'Select Product Category', 'food-restro-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'food-restro-pro' ),
	'section'           => 'food_restro_pro_special_menu_section',
	'taxonomy'			=> 'product_cat',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'food_restro_pro_is_special_menu_section_content_product_category_enable'
) ) );