<?php
/**
 * Special Offer Section options
 *
 * @package Theme Palace
 * @subpackage Food Restro Pro
 * @since Food Restro Pro 1.0.0
 */

// Add Special Offer section
$wp_customize->add_section( 'food_restro_pro_special_offer_section', array(
	'title'             => esc_html__( 'Special Offer','food-restro-pro' ),
	'description'       => esc_html__( 'Special Offer Section options.', 'food-restro-pro' ),
	'panel'             => 'food_restro_pro_front_page_panel',
) );

// Special Offer content enable control and setting
$wp_customize->add_setting( 'food_restro_pro_theme_options[special_offer_section_enable]', array(
	'default'			=> 	$options['special_offer_section_enable'],
	'sanitize_callback' => 'food_restro_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Food_Restro_Pro_Switch_Control( $wp_customize, 'food_restro_pro_theme_options[special_offer_section_enable]', array(
	'label'             => esc_html__( 'Special Offer Section Enable', 'food-restro-pro' ),
	'section'           => 'food_restro_pro_special_offer_section',
	'on_off_label' 		=> food_restro_pro_switch_options(),
) ) );

// special offer subtitle setting and control
$wp_customize->add_setting( 'food_restro_pro_theme_options[special_offer_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['special_offer_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'food_restro_pro_theme_options[special_offer_subtitle]', array(
	'label'           	=> esc_html__( 'Sub Title', 'food-restro-pro' ),
	'section'        	=> 'food_restro_pro_special_offer_section',
	'active_callback' 	=> 'food_restro_pro_is_special_offer_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'food_restro_pro_theme_options[special_offer_subtitle]', array(
		'selector'            => '#special-offer .section-header p.section-subtitle',
		'settings'            => 'food_restro_pro_theme_options[special_offer_subtitle]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'food_restro_pro_special_offer_subtitle_partial',
    ) );
}

// Special Offer content type control and setting
$wp_customize->add_setting( 'food_restro_pro_theme_options[special_offer_content_type]', array(
	'default'          	=> $options['special_offer_content_type'],
	'sanitize_callback' => 'food_restro_pro_sanitize_select',
) );

$wp_customize->add_control( 'food_restro_pro_theme_options[special_offer_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'food-restro-pro' ),
	'section'           => 'food_restro_pro_special_offer_section',
	'type'				=> 'select',
	'active_callback' 	=> 'food_restro_pro_is_special_offer_section_enable',
	'choices'			=> food_restro_pro_special_offer_content_type(),
) );

// special offer pages drop down chooser control and setting
$wp_customize->add_setting( 'food_restro_pro_theme_options[special_offer_content_page]', array(
	'sanitize_callback' => 'food_restro_pro_sanitize_page',
) );

$wp_customize->add_control( new Food_Restro_Pro_Dropdown_Chooser( $wp_customize, 'food_restro_pro_theme_options[special_offer_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'food-restro-pro' ),
	'section'           => 'food_restro_pro_special_offer_section',
	'choices'			=> food_restro_pro_page_choices(),
	'active_callback'	=> 'food_restro_pro_is_special_offer_section_content_page_enable',
) ) );

// special offer posts drop down chooser control and setting
$wp_customize->add_setting( 'food_restro_pro_theme_options[special_offer_content_post]', array(
	'sanitize_callback' => 'food_restro_pro_sanitize_page',
) );

$wp_customize->add_control( new Food_Restro_Pro_Dropdown_Chooser( $wp_customize, 'food_restro_pro_theme_options[special_offer_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'food-restro-pro' ),
	'section'           => 'food_restro_pro_special_offer_section',
	'choices'			=> food_restro_pro_post_choices(),
	'active_callback'	=> 'food_restro_pro_is_special_offer_section_content_post_enable',
) ) );

// special offer posts drop down chooser control and setting
$wp_customize->add_setting( 'food_restro_pro_theme_options[special_offer_content_product]', array(
	'sanitize_callback' => 'food_restro_pro_sanitize_page',
) );

$wp_customize->add_control( new Food_Restro_Pro_Dropdown_Chooser( $wp_customize, 'food_restro_pro_theme_options[special_offer_content_product]', array(
	'label'             => esc_html__( 'Select Product', 'food-restro-pro' ),
	'section'           => 'food_restro_pro_special_offer_section',
	'choices'			=> food_restro_pro_product_choices(),
	'active_callback'	=> 'food_restro_pro_is_special_offer_section_content_product_enable',
) ) );

// special offer title setting and control
$wp_customize->add_setting( 'food_restro_pro_theme_options[special_offer_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['special_offer_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'food_restro_pro_theme_options[special_offer_title]', array(
	'label'           	=> esc_html__( 'Title', 'food-restro-pro' ),
	'section'        	=> 'food_restro_pro_special_offer_section',
	'active_callback' 	=> 'food_restro_pro_is_special_offer_section_content_custom_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'food_restro_pro_theme_options[special_offer_title]', array(
		'selector'            => '#special-offer .entry-container .section-header h2.section-title',
		'settings'            => 'food_restro_pro_theme_options[special_offer_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'food_restro_pro_special_offer_title_partial',
    ) );
}

// special offer description setting and control
$wp_customize->add_setting( 'food_restro_pro_theme_options[special_offer_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'			=> $options['special_offer_description'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'food_restro_pro_theme_options[special_offer_description]', array(
	'label'           	=> esc_html__( 'Description', 'food-restro-pro' ),
	'section'        	=> 'food_restro_pro_special_offer_section',
	'active_callback' 	=> 'food_restro_pro_is_special_offer_section_content_custom_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'food_restro_pro_theme_options[special_offer_description]', array(
		'selector'            => '#special-offer .entry-container .entry-content',
		'settings'            => 'food_restro_pro_theme_options[special_offer_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'food_restro_pro_special_offer_description_partial',
    ) );
}

// special offer image setting and control.
$wp_customize->add_setting( 'food_restro_pro_theme_options[special_offer_image]', array(
	'sanitize_callback' => 'food_restro_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'food_restro_pro_theme_options[special_offer_image]',
		array(
		'label'       		=> esc_html__( 'Image', 'food-restro-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'food-restro-pro' ), 512, 520 ),
		'section'     		=> 'food_restro_pro_special_offer_section',
		'active_callback'	=> 'food_restro_pro_is_special_offer_section_content_custom_enable',
) ) );

// special offer btn title setting and control
$wp_customize->add_setting( 'food_restro_pro_theme_options[special_offer_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'food_restro_pro_theme_options[special_offer_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'food-restro-pro' ),
	'section'        	=> 'food_restro_pro_special_offer_section',
	'active_callback' 	=> 'food_restro_pro_is_special_offer_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'food_restro_pro_theme_options[special_offer_btn_title]', array(
		'selector'            => '#special-offer .read-more a',
		'settings'            => 'food_restro_pro_theme_options[special_offer_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'food_restro_pro_special_offer_btn_title_partial',
    ) );
}

// special offer btn link setting and control
$wp_customize->add_setting( 'food_restro_pro_theme_options[special_offer_btn_link]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'food_restro_pro_theme_options[special_offer_btn_link]', array(
	'label'           	=> esc_html__( 'Button Link', 'food-restro-pro' ),
	'section'        	=> 'food_restro_pro_special_offer_section',
	'active_callback' 	=> 'food_restro_pro_is_special_offer_section_content_custom_enable',
	'type'				=> 'url',
) );