<?php
/**
 * Theme Palace options
 *
 * @package Theme Palace
 * @subpackage Food Restro Pro
 * @since Food Restro Pro 1.0.0
 */

/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */
function food_restro_pro_page_choices() {
    $pages = get_pages();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'food-restro-pro' );
    foreach ( $pages as $page ) {
        $choices[ $page->ID ] = $page->post_title;
    }
    return  $choices;
}

/**
 * List of posts for post choices.
 * @return Array Array of post ids and name.
 */
function food_restro_pro_post_choices() {
    $posts = get_posts( array( 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'food-restro-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of products for post choices.
 * @return Array Array of post ids and name.
 */
function food_restro_pro_product_choices() {
    $posts = get_posts( array( 'numberposts' => -1, 'post_type' => 'product' ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'food-restro-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

if ( ! function_exists( 'food_restro_pro_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function food_restro_pro_typography_options(){
        $choices = array(
            'default'         => esc_html__( 'Default', 'food-restro-pro' ),
            'header-font-1'   => esc_html__( 'Rajdhani', 'food-restro-pro' ),
            'header-font-2'   => esc_html__( 'Cherry Swash', 'food-restro-pro' ),
            'header-font-3'   => esc_html__( 'Philosopher', 'food-restro-pro' ),
            'header-font-4'   => esc_html__( 'Slabo 27px', 'food-restro-pro' ),
            'header-font-5'   => esc_html__( 'Dosis', 'food-restro-pro' ),
        );

        $output = apply_filters( 'food_restro_pro_typography_options', $choices );
        if ( ! empty( $output ) ) {
            ksort( $output );
        }

        return $output;
    }
endif;


if ( ! function_exists( 'food_restro_pro_body_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function food_restro_pro_body_typography_options(){
        $choices = array(
            'default'         => esc_html__( 'Default', 'food-restro-pro' ),
            'body-font-1'     => esc_html__( 'News Cycle', 'food-restro-pro' ),
            'body-font-2'     => esc_html__( 'Pontano Sans', 'food-restro-pro' ),
            'body-font-3'     => esc_html__( 'Gudea', 'food-restro-pro' ),
            'body-font-4'     => esc_html__( 'Quattrocento', 'food-restro-pro' ),
            'body-font-5'     => esc_html__( 'Khand', 'food-restro-pro' ),
        );

        $output = apply_filters( 'food_restro_pro_body_typography_options', $choices );
        if ( ! empty( $output ) ) {
            ksort( $output );
        }

        return $output;
    }
endif;


if ( ! function_exists( 'food_restro_pro_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function food_restro_pro_site_layout() {
        $food_restro_pro_site_layout = array(
            'wide'  => get_template_directory_uri() . '/assets/images/full.png',
            'boxed-layout' => get_template_directory_uri() . '/assets/images/boxed.png',
            'frame-layout' => get_template_directory_uri() . '/assets/images/framed.png',
        );

        $output = apply_filters( 'food_restro_pro_site_layout', $food_restro_pro_site_layout );
        return $output;
    }
endif;

if ( ! function_exists( 'food_restro_pro_selected_sidebar' ) ) :
    /**
     * Sidebars options
     * @return array Sidbar positions
     */
    function food_restro_pro_selected_sidebar() {
        $food_restro_pro_selected_sidebar = array(
            'sidebar-1'             => esc_html__( 'Default Sidebar', 'food-restro-pro' ),
            'optional-sidebar'      => esc_html__( 'Optional Sidebar 1', 'food-restro-pro' ),
            'optional-sidebar-2'    => esc_html__( 'Optional Sidebar 2', 'food-restro-pro' ),
            'optional-sidebar-3'    => esc_html__( 'Optional Sidebar 3', 'food-restro-pro' ),
            'optional-sidebar-4'    => esc_html__( 'Optional Sidebar 4', 'food-restro-pro' ),
        );

        $output = apply_filters( 'food_restro_pro_selected_sidebar', $food_restro_pro_selected_sidebar );

        return $output;
    }
endif;


if ( ! function_exists( 'food_restro_pro_global_sidebar_position' ) ) :
    /**
     * Global Sidebar position
     * @return array Global Sidebar positions
     */
    function food_restro_pro_global_sidebar_position() {
        $food_restro_pro_global_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
        );

        $output = apply_filters( 'food_restro_pro_global_sidebar_position', $food_restro_pro_global_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'food_restro_pro_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function food_restro_pro_sidebar_position() {
        $food_restro_pro_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
            'no-sidebar-content'   => get_template_directory_uri() . '/assets/images/boxed.png',
        );

        $output = apply_filters( 'food_restro_pro_sidebar_position', $food_restro_pro_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'food_restro_pro_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function food_restro_pro_pagination_options() {
        $food_restro_pro_pagination_options = array(
            'numeric'   => esc_html__( 'Numeric', 'food-restro-pro' ),
            'default'   => esc_html__( 'Default(Older/Newer)', 'food-restro-pro' ),
            'infinite'  => esc_html__( 'Infinite', 'food-restro-pro' ),
        );

        $output = apply_filters( 'food_restro_pro_pagination_options', $food_restro_pro_pagination_options );

        return $output;
    }
endif;

if ( ! function_exists( 'food_restro_pro_get_spinner_list' ) ) :
    /**
     * List of spinner icons options.
     * @return array List of all spinner icon options.
     */
    function food_restro_pro_get_spinner_list() {
        $arr = array(
            'default'               => esc_html__( 'Default', 'food-restro-pro' ),
            'spinner-wheel'         => esc_html__( 'Wheel', 'food-restro-pro' ),
            'spinner-double-circle' => esc_html__( 'Double Circle', 'food-restro-pro' ),
            'spinner-two-way'       => esc_html__( 'Two Way', 'food-restro-pro' ),
            'spinner-umbrella'      => esc_html__( 'Umbrella', 'food-restro-pro' ),
            'spinner-dots'          => esc_html__( 'Dots', 'food-restro-pro' ),
            'spinner-one-way'       => esc_html__( 'One Way', 'food-restro-pro' ),
            'spinner-fidget'        => esc_html__( 'Fidget', 'food-restro-pro' ),
        );
        return apply_filters( 'food_restro_pro_spinner_list', $arr );
    }
endif;

if ( ! function_exists( 'food_restro_pro_switch_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function food_restro_pro_switch_options() {
        $arr = array(
            'on'        => esc_html__( 'Enable', 'food-restro-pro' ),
            'off'       => esc_html__( 'Disable', 'food-restro-pro' )
        );
        return apply_filters( 'food_restro_pro_switch_options', $arr );
    }
endif;

if ( ! function_exists( 'food_restro_pro_hide_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function food_restro_pro_hide_options() {
        $arr = array(
            'on'        => esc_html__( 'Yes', 'food-restro-pro' ),
            'off'       => esc_html__( 'No', 'food-restro-pro' )
        );
        return apply_filters( 'food_restro_pro_hide_options', $arr );
    }
endif;

if ( ! function_exists( 'food_restro_pro_sortable_sections' ) ) :
    /**
     * List of sections Control options
     * @return array List of Sections control options.
     */
    function food_restro_pro_sortable_sections() {
        $sections = array(
            'slider'    => esc_html__( 'Main Slider', 'food-restro-pro' ),
            'service'   => esc_html__( 'Services', 'food-restro-pro' ),
            'about'     => esc_html__( 'About Us', 'food-restro-pro' ),
            'special_menu' => esc_html__( 'Special Menu', 'food-restro-pro' ),
            'special_offer' => esc_html__( 'Special Offer', 'food-restro-pro' ),
            'gallery'   => esc_html__( 'Gallery', 'food-restro-pro' ),
            'testimonial' => esc_html__( 'Testimonial', 'food-restro-pro' ),
            'cta'       => esc_html__( 'Call to Action', 'food-restro-pro' ),
            'blog'      => esc_html__( 'Blog', 'food-restro-pro' ),
        );
        return apply_filters( 'food_restro_pro_sortable_sections', $sections );
    }
endif;

if ( ! function_exists( 'food_restro_pro_special_offer_content_type' ) ) :
    /**
     * Special Offer Options
     * @return array site special_offer options
     */
    function food_restro_pro_special_offer_content_type() {
        $food_restro_pro_special_offer_content_type = array(
            'page'      => esc_html__( 'Page', 'food-restro-pro' ),
            'post'      => esc_html__( 'Post', 'food-restro-pro' ),
            'custom'    => esc_html__( 'Custom', 'food-restro-pro' ),
        );

        if ( class_exists( 'WooCommerce' ) ) {
            $food_restro_pro_special_offer_content_type = array_merge( $food_restro_pro_special_offer_content_type, array(
                'product'   => esc_html__( 'Product', 'food-restro-pro' ),
                ) );
        }

        $output = apply_filters( 'food_restro_pro_special_offer_content_type', $food_restro_pro_special_offer_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'food_restro_pro_gallery_content_type' ) ) :
    /**
     * Gallery Options
     * @return array site gallery options
     */
    function food_restro_pro_gallery_content_type() {
        $food_restro_pro_gallery_content_type = array(
            'page'      => esc_html__( 'Page', 'food-restro-pro' ),
            'post'      => esc_html__( 'Post', 'food-restro-pro' ),
            'category'  => esc_html__( 'Category', 'food-restro-pro' ),
        );

        if ( class_exists( 'WooCommerce' ) ) {
            $food_restro_pro_gallery_content_type = array_merge( $food_restro_pro_gallery_content_type, array(
                'product'   => esc_html__( 'Product', 'food-restro-pro' ),
                'product-category'   => esc_html__( 'Product Category', 'food-restro-pro' ),
                ) );
        }

        $output = apply_filters( 'food_restro_pro_gallery_content_type', $food_restro_pro_gallery_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'food_restro_pro_special_menu_content_type' ) ) :
    /**
     * Special Menu Options
     * @return array site special menu options
     */
    function food_restro_pro_special_menu_content_type() {
        $food_restro_pro_special_menu_content_type = array(
            'page'      => esc_html__( 'Page', 'food-restro-pro' ),
            'post'      => esc_html__( 'Post', 'food-restro-pro' ),
            'category'  => esc_html__( 'Category', 'food-restro-pro' ),
        );

        if ( class_exists( 'WooCommerce' ) ) {
            $food_restro_pro_special_menu_content_type = array_merge( $food_restro_pro_special_menu_content_type, array(
                'product'   => esc_html__( 'Product', 'food-restro-pro' ),
                'product-category'   => esc_html__( 'Product Category', 'food-restro-pro' ),
                ) );
        }

        $output = apply_filters( 'food_restro_pro_special_menu_content_type', $food_restro_pro_special_menu_content_type );


        return $output;
    }
endif;
